Package: dyn
Version: 0.2-9.6
Date: 2018-03-18
Title: Time Series Regression
Author: G. Grothendieck
Maintainer: M. Leeds <markleeds2@gmail.com>
Description: Time series regression.  The dyn class interfaces ts,
        irts(), zoo() and zooreg() time series classes to lm(), glm(),
        loess(), quantreg::rq(), MASS::rlm(), MCMCpack::MCMCregress(),
        quantreg::rq(), randomForest::randomForest() and other regression
        functions allowing those functions to be used with time series
        including specifications that may contain lags, diffs and
        missing values.
Depends: R (>= 2.6.0), zoo (>= 1.0-0)
Suggests: lattice, MASS, MCMCpack, quantreg (>= 3.82), randomForest,
        sandwich, tseries
License: GPL
Packaged: 2018-03-19 05:44:27 UTC; home
Repository: CRAN
Date/Publication: 2018-03-19 06:14:06 UTC
NeedsCompilation: no
Built: R 4.6.0; ; 2026-04-27 08:55:15 UTC; unix
