
dyn is an R package that facilitates the use of regression
using time series data with lags and diffs (known as dynamic
regression).  It is a lightweight package that has no
facilities of its own but leverages off the various time
series and regression functions in R to make it easier to
use them together.

Its features include:

- many regression functions.  It can be used with lm, glm,
  loess, rq, randomForest, lqs, rlm and any other regression 
  functions that use model.frame and are written in the
  style of lm.

- many time series classes. It can be used with ts, zooreg,
  zoo, its, and irts time series classes.  This covers
  regular, weakly regular and irregular time series classes.

- missing values.  Time series may have missing values including
  internal missing values.  Both na.omit and na.exclude are
  supported.  

- good citizen.  It does not replace the regression
  functions but rather works with them by providing new
  methods to the standard R generics: model.frame, resid,
  fitted, predict, update, anova and $.

- ease of use.  dyn enables one to use the same regression
  functions (lm, glm, etc.) using the same syntax one has
  always used.  Just preface the regression function name with 
  dyn$ and it is transformed into a regression function that 
  can handle time series:

   dyn$lm( y ~ x + lag(x) + diff(w) )     # lm
   dyn$loess( y ~ x + lag(x) + diff(w) )  # loess

- modular.  dyn can be used with any regression function that
  uses model.frame and is written in the style of lm.  Additional
  classes can be added to dyn simply by adding new methods. dyn
  is modular so such updates can be made without changing dyn, 
  itself. 

- documentation.  It includes a help page and six demos.

   ?dyn                   # help file
   demo(package = "dyn")  # list of demos
   demo("dyn-rq")         # runs indicated dyn demo

   # other information
   file.show(system.file("NEWS", package = "dyn"))  
   file.show(system.file("README", package = "dyn") # this file
   file.show(system.file("THANKS", package = "dyn"))
   file.show(system.file("WISHLIST", package = "dyn"))

The package is available on CRAN.  Comments/questions welcome.

