=pod

=encoding utf-8

=head1 NAME

Dyn::Call::Aggregate - C interface to compute struct size

=head1 DESCRIPTION

It's a void pointer. Make whatever you want with it.

=head1 Functions


=head1 LICENSE

Copyright (C) Sanko Robinson.

This library is free software; you can redistribute it and/or modify it under
the terms found in the Artistic License 2. Other copyrights, terms, and
conditions may apply to data transmitted through this module.

=head1 AUTHOR

Sanko Robinson E<lt>sanko@cpan.orgE<gt>

=begin stopwords

dyncall const deallocated

=end stopwords

=cut